import { sync } from '@genesislcap/foundation-utils';
import { html, repeat, ref, when, slotted } from '@microsoft/fast-element';
import { whitespaceFilter } from '@microsoft/fast-foundation';
import { classNames } from '@microsoft/fast-web-utilities';
import { MultiselectDatasource } from '../options-datasource';
const ARROW_SVG_PATH = 'M11.85.65c.2.2.2.5 0 .7L6.4 6.84a.55.55 0 01-.78 0L.14 1.35a.5.5 0 11.71-.7L6 5.8 11.15.65c.2-.2.5-.2.7 0z';
export const getPrefixedMultiselect = (prefix = 'foundation') => html `
  <label
    part="label"
    for="display-field"
    class=${(x) => { var _a; return classNames('label', ['label-hidden', !((_a = x.defaultSlottedNodes) === null || _a === void 0 ? void 0 : _a.length)]); }}
  >
    <slot
      name="label"
      ${slotted({
    property: 'defaultSlottedNodes',
    filter: whitespaceFilter,
})}
    ></slot>
  </label>
  <div class="root" part="root" @keydown="${(x, c) => x.keydownHandler(c.event)}">
    <div class="control" part="control">
      <input
        id="display-field"
        part="filter-search"
        role="combobox"
        aria-haspopup="listbox"
        aria-controls="checkbox-container"
        aria-expanded=${(x) => (x.open ? 'true' : 'false')}
        ?readonly=${(x) => !x.search}
        @click=${(x) => x.toggle()}
        ?disabled="${(x) => x.disabled}"
        value=${sync((x) => x.filterSearchValue, 'string', 'input')}
        placeholder="${(x) => x.getDisplayValue}"
        @input=${(x, c) => x.inputHandler()}
        @change=${(x, c) => x.changeHandler(c.event)}
      />
      <div part="indicator" class="indicator" @click=${(x) => !x.disabled && x.toggle()}>
        <svg
          viewBox="0 0 12 7"
          ${ref('arrowIcon')}
          id="arrow-icon"
          class="${(x) => classNames(['disabled-svg', x.disabled])}"
          xmlns="http://www.w3.org/2000/svg"
        >
          <path d="${ARROW_SVG_PATH}" />
        </svg>
      </div>
      ${when((x) => x.filterSearchValue && x.selectedOptions.length, html `
          <div class="display-value">${(x) => x.getDisplayValue}</div>
        `)}
    </div>
    ${when((x) => x.loading, html `
          <${prefix}-progress slot="indicator"></${prefix}-progress>
        `)}
    <ol
      ${ref('optionsElement')}
      id="checkbox-container"
      class="checkbox-container options"
      aria-multiselectable="true"
    >
      ${when((x) => x.all, html `
          <${prefix}-button
            class="select-all"
            @click=${(x) => x.selectCheckboxAll()}
            ?disabled="${(x, c) => x.isAllOptionsDisabled}"
          >
            Select All ${(x) => x.name}
          </${prefix}-button>
        `)}
      ${repeat((x) => x.filteredAvailableOptions, html `
          <li role="option" value=${(x, ctx) => ctx.parent.getItemLabel(x)}>
            <${prefix}-checkbox
              part="checkbox"
              class="checkbox"
              @keydown=${(x, c) => c.parent.checkboxKeyDown(x, c.event)}
              @click=${(x, c) => c.parent.selectCheckboxOne(x)}
              @change=${(x, c) => c.parent.changeHandler(c.event)}
              ?current-checked="${(x, c) => c.parent.isOptionSelected(x)}"
              ?disabled="${(x, c) => c.parent.isOptionDisabled(x)}"
            >
              ${(x, ctx) => ctx.parent.getItemLabel(x)}
            </${prefix}-checkbox>
          </li>
        `)}
      ${when((x) => x.showCreatable, html `
          <${prefix}-button @click=${(x) => x.addOption()}>Create&nbsp;"${(x) => x.filterSearchValue}"</${prefix}-button>
        `)}
    </ol>
  </div>
  <slot
    ${slotted({
    property: 'slottedDatasource',
    filter: (x) => x instanceof MultiselectDatasource,
})}
  ></slot>
`;
export const multiselectTemplate = html `
  ${getPrefixedMultiselect()}
`;
